@@ -13,8 +13,7 @@ BEGIN {
     }
 }
 
-our $VERSION = '0.04_002';
-$VERSION =~ tr/_//d;
+our $VERSION = '0.01';
 
 our @EXPORT_OK = qw(
     GRND_RANDOM
@@ -152,8 +151,16 @@ To install this module, run the following commands:
     make test
     make install
 
-The F<syscall.h> and F<sys/random.h> headers in F</usr/include> (or at least
-their Perl versions as generated by the L<h2ph> tool) must be available.
+Perl versions of the F<syscall.h> and F<sys/random.h> headers (as
+generated by the L<h2ph> tool) must be available. If you are using perl from a
+system package, this should have already been done for you. If you have built
+your own perl (and you have write permissions on its module directories), you
+may have to run this command first:
+
+    cd /usr/include && h2ph -eal syscall.h sys/random.h
+
+Apparent errors about missing internal headers such as C<Can't open
+gnu/stubs-32.h: No such file or directory> can be ignored.
 
 =head1 SUPPORT AND DOCUMENTATION
 
